==> alg-common-1.22.1-20191009.085457-1-sources.jar: cn/com/duiba/nezha/alg/common/model/activityrecommend/ActivityMatchInfo.java <==
package cn.com.duiba.nezha.alg.common.model.activityrecommend;

/**
 *功能描述 广告位下海选结果
 * @author lijingzhe
 * @date 2019/9/3
 * @param
 * @return
 */
public class ActivityMatchInfo {
    /**
     * 活动id
     */
    long activityId;
    /**
     * 广告位id
     */
    long slotId;
    /**
     * 媒体id
     */
    long appId;
    /**
     * 转化分
     */
    double changeScore;
    /**
     * 广告位+媒体+全局维度活动请求/访问
     */
    ActivityVal hisRequest = new ActivityVal();
    /**
     * 广告位+媒体+全局维度券点击
     */
    ActivityVal hisClick = new ActivityVal();
    /**
     * 广告位+媒体+全局维度消耗
     */
    ActivityVal hisCost = new ActivityVal();
    /**
     * 活动维度广告明细
     */
    ActivityCvrInfo activityChangeVal;

    /**
     * v4.0 皮肤含有ops或vm新活动 1;否则老活动 0
     */
    int subType = 0;
    /**
     * 活动类型
     */
    long activityType;
    /**
     * 是否是优质活动
     */
    boolean isExcellent = false;
    /**
     * 归一化每pv券点击
     */
    double nPvClick;
    /**
     * 归一化每pv消耗
     */
    double nPvCost;
    /**
     * 归一化表单类cvr
     */
    double nCvrForm;
    /**
     * 归一化非表单类cvr
     */
    double nCvrNotForm;
    /**
     * 归一化cvr
     */
    double nCvr;
    /**
     * 归一化得分
     */
    double score;

    public long getActivityId() {
        return activityId;
    }

    public void setActivityId(long activityId) {
        this.activityId = activityId;
    }

    public long getSlotId() {
        return slotId;
    }

    public void setSlotId(long slotId) {
        this.slotId = slotId;
    }

    public long getAppId() {
        return appId;
    }

    public void setAppId(long appId) {
        this.appId = appId;
    }

    public double getChangeScore() {
        return changeScore;
    }

    public void setChangeScore(double changeScore) {
        this.changeScore = changeScore;
    }

    public ActivityVal getHisRequest() {
        return hisRequest;
    }

    public void setHisRequest(ActivityVal hisRequest) {
        this.hisRequest = hisRequest;
    }

    public ActivityVal getHisClick() {
        return hisClick;
    }

    public void setHisClick(ActivityVal hisClick) {
        this.hisClick = hisClick;
    }

    public ActivityVal getHisCost() {
        return hisCost;
    }

    public void setHisCost(ActivityVal hisCost) {
        this.hisCost = hisCost;
    }

    public ActivityCvrInfo getActivityChangeVal() {
        return activityChangeVal;
    }

    public void setActivityChangeVal(ActivityCvrInfo activityChangeVal) {
        this.activityChangeVal = activityChangeVal;
    }

    public int getSubType() {
        return subType;
    }

    public void setSubType(int subType) {
        this.subType = subType;
    }

    public long getActivityType() {
        return activityType;
    }

    public void setActivityType(long activityType) {
        this.activityType = activityType;
    }

    public boolean isExcellent() {
        return isExcellent;
    }

    public void setExcellent(boolean excellent) {
        isExcellent = excellent;
    }

    public double getnPvClick() {
        return nPvClick;
    }

    public void setnPvClick(double nPvClick) {
        this.nPvClick = nPvClick;
    }

    public double getnPvCost() {
        return nPvCost;
    }

    public void setnPvCost(double nPvCost) {
        this.nPvCost = nPvCost;
    }

    public double getnCvrForm() {
        return nCvrForm;
    }

    public void setnCvrForm(double nCvrForm) {
        this.nCvrForm = nCvrForm;
    }

    public double getnCvrNotForm() {
        return nCvrNotForm;
    }

    public void setnCvrNotForm(double nCvrNotForm) {
        this.nCvrNotForm = nCvrNotForm;
    }

    public double getnCvr() {
        return nCvr;
    }

    public void setnCvr(double nCvr) {
        this.nCvr = nCvr;
    }

    public double getScore() {
        return score;
    }

    public void setScore(double score) {
        this.score = score;
    }
}

==> alg-common-1.40.1-sources.jar: cn/com/duiba/nezha/alg/common/model/activityrecommend/ActivityMatchInfo.java <==
package cn.com.duiba.nezha.alg.common.model.activityrecommend;

/**
 *功能描述 广告位下海选结果
 * @author lijingzhe
 * @date 2019/9/3
 * @param
 * @return
 */
public class ActivityMatchInfo {
    /**
     * 活动id
     */
    long activityId;
    /**
     * 广告位id
     */
    long slotId;
    /**
     * 媒体id
     */
    long appId;
    /**
     * 转化分
     */
    double changeScore;
    /**
     * 广告位+媒体+全局维度活动请求/访问
     */
    ActivityVal hisRequest = new ActivityVal();
    /**
     * 广告位+媒体+全局维度券点击
     */
    ActivityVal hisClick = new ActivityVal();
    /**
     * 广告位+媒体+全局维度消耗
     */
    ActivityVal hisCost = new ActivityVal();
    /**
     * 广告位+媒体+全局维度转化
     */
    ActivityVal hisEffect = new ActivityVal();
    /**
     * 活动维度广告明细
     */
    ActivityCvrInfo activityChangeVal;

    /**
     * v4.0 皮肤含有ops或vm新活动 1;否则老活动 0
     */
    int subType = 0;
    /**
     * 活动类型
     */
    long activityType;
    /**
     * 是否是优质活动
     */
    boolean isExcellent = false;
    /**
     * 归一化每pv券点击
     */
    double nPvClick;
    /**
     * 归一化每pv消耗
     */
    double nPvCost;
    /**
     * 归一化表单类cvr
     */
    double nCvrForm;
    /**
     * 归一化非表单类cvr
     */
    double nCvrNotForm;
    /**
     * 归一化cvr
     */
    double nCvr;
    /**
     * 归一化得分
     */
    double score;
    /**
     * 广告位cvr
     */
    double cvrBias;
    /**
     * 广告位每uv消耗
     */
    double uvCost;
    /**
     * 广告位每uv券点击
     */
    double uvClick;
    /**
     * 广告位真实cvr
     */
    double cvr;
    /**
     * 最近15天首次曝光每uv消耗涨幅
     */
    double ucRate = 0;
    /**
     * v4.8, 是否热点活动, 是true
     */
    boolean isSupport;

    public long getActivityId() {
        return activityId;
    }

    public void setActivityId(long activityId) {
        this.activityId = activityId;
    }

    public long getSlotId() {
        return slotId;
    }

    public void setSlotId(long slotId) {
        this.slotId = slotId;
    }

    public long getAppId() {
        return appId;
    }

    public void setAppId(long appId) {
        this.appId = appId;
    }

    public double getChangeScore() {
        return changeScore;
    }

    public void setChangeScore(double changeScore) {
        this.changeScore = changeScore;
    }

    public ActivityVal getHisRequest() {
        return hisRequest;
    }

    public void setHisRequest(ActivityVal hisRequest) {
        this.hisRequest = hisRequest;
    }

    public ActivityVal getHisClick() {
        return hisClick;
    }

    public void setHisClick(ActivityVal hisClick) {
        this.hisClick = hisClick;
    }

    public ActivityVal getHisCost() {
        return hisCost;
    }

    public void setHisCost(ActivityVal hisCost) {
        this.hisCost = hisCost;
    }

    public ActivityCvrInfo getActivityChangeVal() {
        return activityChangeVal;
    }

    public void setActivityChangeVal(ActivityCvrInfo activityChangeVal) {
        this.activityChangeVal = activityChangeVal;
    }

    public int getSubType() {
        return subType;
    }

    public void setSubType(int subType) {
        this.subType = subType;
    }

    public long getActivityType() {
        return activityType;
    }

    public void setActivityType(long activityType) {
        this.activityType = activityType;
    }

    public boolean isExcellent() {
        return isExcellent;
    }

    public void setExcellent(boolean excellent) {
        isExcellent = excellent;
    }

    public double getnPvClick() {
        return nPvClick;
    }

    public void setnPvClick(double nPvClick) {
        this.nPvClick = nPvClick;
    }

    public double getnPvCost() {
        return nPvCost;
    }

    public void setnPvCost(double nPvCost) {
        this.nPvCost = nPvCost;
    }

    public double getnCvrForm() {
        return nCvrForm;
    }

    public void setnCvrForm(double nCvrForm) {
        this.nCvrForm = nCvrForm;
    }

    public double getnCvrNotForm() {
        return nCvrNotForm;
    }

    public void setnCvrNotForm(double nCvrNotForm) {
        this.nCvrNotForm = nCvrNotForm;
    }

    public double getnCvr() {
        return nCvr;
    }

    public void setnCvr(double nCvr) {
        this.nCvr = nCvr;
    }

    public double getScore() {
        return score;
    }

    public void setScore(double score) {
        this.score = score;
    }

    public double getCvrBias() {
        return cvrBias;
    }

    public void setCvrBias(double cvrBias) {
        this.cvrBias = cvrBias;
    }

    public double getUvCost() {
        return uvCost;
    }

    public void setUvCost(double uvCost) {
        this.uvCost = uvCost;
    }

    public double getUvClick() {
        return uvClick;
    }

    public void setUvClick(double uvClick) {
        this.uvClick = uvClick;
    }

    public double getCvr() {
        return cvr;
    }

    public void setCvr(double cvr) {
        this.cvr = cvr;
    }

    public ActivityVal getHisEffect() {
        return hisEffect;
    }

    public void setHisEffect(ActivityVal hisEffect) {
        this.hisEffect = hisEffect;
    }

    public double getUcRate() {
        return ucRate;
    }

    public void setUcRate(double ucRate) {
        this.ucRate = ucRate;
    }

    public boolean isSupport() {
        return isSupport;
    }

    public void setSupport(boolean support) {
        isSupport = support;
    }

    @Override
    public String toString() {
        return "ActivityMatchInfo{" +
                "activityId=" + activityId +
                ", slotId=" + slotId +
                ", appId=" + appId +
                ", changeScore=" + changeScore +
                ", hisRequest=" + hisRequest +
                ", hisClick=" + hisClick +
                ", hisCost=" + hisCost +
                ", hisEffect=" + hisEffect +
                ", activityChangeVal=" + activityChangeVal +
                ", subType=" + subType +
                ", activityType=" + activityType +
                ", isExcellent=" + isExcellent +
                ", nPvClick=" + nPvClick +
                ", nPvCost=" + nPvCost +
                ", nCvrForm=" + nCvrForm +
                ", nCvrNotForm=" + nCvrNotForm +
                ", nCvr=" + nCvr +
                ", score=" + score +
                ", cvrBias=" + cvrBias +
                ", uvCost=" + uvCost +
                ", uvClick=" + uvClick +
                ", cvr=" + cvr +
                ", ucRate=" + ucRate +
                ", isSupport=" + isSupport +
                '}';
    }
}
